const { mpserverless } = getApp()

Page({
  data: {
    imgs: [],
    url: ''
  },
  onLoad(query) {
    // 页面加载
    this.setData({
      album: query.album
    })
    my.setNavigationBar({
      title: this.data.album,
    })
  },
  async onReady() {
    // 页面加载完成
    try {
      const photoList = await my.serverless.function.invoke('PhotoServer', {
        action: 'ListPhoto',
        params: {
          album: this.data.album
        }
      })
      if (photoList && photoList.success) {
        this.setData({
          imgs: photoList.result.map(el => el.url)
        })
      }
    } catch (e) {
      my.showToast(
        { content: '获取照片列表失败' }
      )
      my.reLaunch({
        url: '/pages/index/index',
      })
    }
  },
  onShow() {
    // 页面显示
  },
  onHide() {
    // 页面隐藏
  },
  onUnload() {
    // 页面被关闭
  },
  onTitleClick() {
    // 标题被点击
  },
  onPullDownRefresh() {
    // 页面被下拉
  },
  onReachBottom() {
    // 页面被拉到底部
  },
  onShareAppMessage() {
    // 返回自定义分享信息
    return {
      title: 'My App',
      desc: 'My App description',
      path: 'pages/index/index',
    };
  },
  // 选择并上传图片，获得图片 URL
  attach() {
    my.chooseImage({
      chooseImage: 1,
      success: async (res) => {
        const path = res.apFilePaths[0];
        const options = {
          filePath: path,
          headers: {
            contentDisposition: 'attachment',
          },
        };
        try {
          const image = await mpserverless.file.uploadFile(options);
          if (image) {
            const url = image.fileUrl;
            const imgs = this.data.imgs;
            imgs.push(url);
            const res = await my.serverless.function.invoke('PhotoServer', {
              action: 'AddPhoto',
              params: { album: this.data.album, url }
            })
            if (res && res.success) {
              this.setData({
                imgs
              })
            }

          }

        } catch (e) {
          my.showToast({
            content: '上传照片失败'
          })
        }
      },
    });
  },
  /** 添加添加照片按钮 */
  onAdd() {
    this.attach()
  },
  /** 单击图片 */
  onImg(node) {
    my.previewImage({
      current: 0,  // 默认显示第三张图片
      urls: [
        node.target.dataset.value,
      ],
      enablesavephoto: true,   // 长按下载
      enableShowPhotoDownload: true,   // 右下角显示下载入口
      success: (res) => {
      },
      fail: (error) => {
      },
    });
  }
});
